# Kumparan-TrendingNews
This package will get the latest Trending News data from Kumparan.com 

## HOW IT WORK
This package will scrape from [Kumparan](https://kumparan.com/trending) to get latest Trending News.

This package will use BeautifulSoup4 and Requests  to produce output in the form of JSON that is ready to be used in web or mobile application.

## HOW TO USE 
```
import Kumparan-TrendingNews
if __name__ == '__main__':
    result = data_extraction()
    show_data(result)
```

# Author
Christian Yurianja